from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.battery_bus import image_template

docs = [
    {
        "path": "../docs/battery_bus/body/li-ion.md",
        "items": ImageItems(
            {
                image_template.format("li-ion/v2/20251211_121307.jpg"): "",
                image_template.format("li-ion/v2/20251211_121319.jpg"): "",
                image_template.format("li-ion/v2/20251211_121331.jpg"): "",
                image_template.format("li-ion/v2/20251211_121339.jpg"): "",
                image_template.format("li-ion/v2/20251211_121344.jpg"): "",
                image_template.format("li-ion/v2/20251211_121349.jpg"): "",
                image_template.format("li-ion/v2/20251211_121357.jpg"): "",
                image_template.format("20251210_204219.jpg"): "",
                image_template.format("20251210_204306.jpg"): "",
            }
        ),
    },
    {
        "path": "../docs/battery_bus/body/li-ion-v1.md",
        "items": ImageItems(
            {
                image_template.format("li-ion/20251204_143912.jpg"): "",
                image_template.format("li-ion/20251204_143924.jpg"): "",
                image_template.format("li-ion/20251204_143931.jpg"): "",
                image_template.format("li-ion/20251204_143944.jpg"): "",
                image_template.format("li-ion/20251204_143949.jpg"): "",
                image_template.format("li-ion/20251204_143958.jpg"): "",
                image_template.format("li-ion/20251204_144045.jpg"): "",
            }
        ),
    },
]



from typing import Dict, List, Any

from bluer_objects import markdown

from bluer_sbc.parts.db import db_of_parts


def design_doc(
    design_name: str,
    items: List[str] = [],
    dict_of_parts: Dict = {},
    macros: Dict[str, Dict] = {},
    own_folder: bool = False,
    parts_reference: str = "./parts",
    cols: int = 3,
) -> Dict[str, Any]:
    macros_ = {}
    if dict_of_parts:
        macros_ = design_doc_parts(
            dict_of_parts,
            parts_reference,
        )

    macros_.update(macros)

    return {
        "path": "../docs/{}{}".format(design_name, "" if own_folder else ".md"),
        "cols": cols,
        "items": items,
        "macros": macros_,
    }


def design_doc_parts(
    dict_of_parts: Dict,
    parts_reference: str = "./parts",
) -> Dict[str, Dict]:
    return {
        "parts_images:::": markdown.generate_table(
            db_of_parts.as_images(
                dict_of_parts,
                reference=parts_reference,
            ),
            cols=10,
            log=False,
        ),
        "parts_list:::": db_of_parts.as_list(
            dict_of_parts,
            reference=parts_reference,
            log=False,
        ),
    }



from bluer_sbc.README.design import design_doc_parts

parts = {
    "SLA-Battery": "option 1️⃣, e.g. 12 V, 7.2 Ah",
    "li-ion-battery": "option 2️⃣, e.g. 3 x 26650, 5000 mAh 5C, 3.7 V/4.2V",
    "dc-switch": "12V DC 10 A",
    "dc-power-plug": "",
    "dsn-vc288": "",
    "connector": "1 male",
}

docs = [
    {
        "path": "../docs/battery_bus/parts.md",
        "macros": design_doc_parts(
            dict_of_parts=parts,
            parts_reference="../parts",
        ),
    }
]



from bluer_objects.README.items import ImageItems
from bluer_objects.README.consts import designs_url

from bluer_sbc.README.designs.battery_bus import image_template

items = ImageItems(
    {
        image_template.format("concept.png"): "",
        designs_url(
            "battery-bus/electrical/wiring.png?raw=true",
        ): designs_url(
            "battery-bus/electrical/wiring.svg",
        ),
        image_template.format("20251007_221902.jpg"): "./body/sla.md",
        image_template.format("li-ion/v2/20251211_121357.jpg"): "./body/li-ion.md",
    }
)



from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.anchor import image_template
from bluer_sbc.README.designs.anchor.body import v1, v2

docs = (
    [
        {
            "path": "../docs/anchor/body",
            "items": ImageItems(
                {
                    image_template.format("v3/20251211_121404.jpg"): "",
                    image_template.format("v3/20251211_121414.jpg"): "",
                    image_template.format("v3/20251211_121420.jpg"): "",
                    image_template.format("v3/20251211_121423.jpg"): "",
                    image_template.format("v3/20251211_121427.jpg"): "",
                    image_template.format("v3/20251211_121435.jpg"): "",
                    image_template.format("v3/20251211_121452.jpg"): "",
                }
            ),
        }
    ]
    + v1.docs
    + v2.docs
)



parts = {
    "rpi-camera": "",
    "ultrasonic-sensor": "4 x",
    "nuts-bolts-spacers": " + ".join(
        [
            "M2: ({})".format(
                " + ".join(
                    [
                        "2 x bolt",
                        "4 x nut",
                        "2 x 5 mm spacer",
                    ]
                )
            ),
            "M3: ({})".format(
                " + ".join(
                    [
                        "4 x 15 mm spacer",
                    ]
                )
            ),
        ]
    ),
    "dupont-cables": "1 x 30 cm + 1 x 10 cm",
    "strong-thread": "1 m",
}
